/*------------------- 
a player entity
-------------------------------- */
var mode = false;
game.PlayerEntity = me.Entity.extend({
 
  /* -----
 
  constructor
 
  ------ */
 	
  init: function(x, y, settings) {
    // call the constructor
    this._super(me.Entity, 'init', [x, y, settings]);
 	//var hey = 1; 
    // set the default horizontal & vertical speed (accel vector)
    this.body.setVelocity(3, 15);
 	//settings.hey = 1;
    // set the display to follow our position on both axis
    me.game.viewport.follow(this.pos, me.game.viewport.AXIS.BOTH);
 
    // ensure the player is updated even when outside of the viewport
    this.alwaysUpdate = true;
     
    // define a basic walking animation (using all frames)
    this.renderable.addAnimation("walk",  [0, 1, 0, 2]);
    this.renderable.addAnimation("swordWalk",  [3, 4, 3, 5]);
    this.renderable.addAnimation("attack",  [6, 7, 8], 150);
    this.renderable.addAnimation("die",  [9, 10, 11]);
    // define a standing animation (using the first frame)
    this.renderable.addAnimation("stand",  [0]);
    this.renderable.addAnimation("swordStand",  [3]);
    // set the standing animation as default
    if(mode == false) {
      this.renderable.setCurrentAnimation("stand");
    } else {
      this.renderable.setCurrentAnimation("swordStand");
    }
    //this.renderable.setCurrentAnimation("attack", 500);
  },
 
  /* -----
 
  update the player pos
 
  ------ */
  update: function(dt) {
    if (me.input.isKeyPressed('left')) {
      // flip the sprite on horizontal axis
      this.renderable.flipX(true);
      // update the entity velocity
      this.body.vel.x -= this.body.accel.x * me.timer.tick;
      // change to the walking animation
      if (mode == false) {
        if (!this.renderable.isCurrentAnimation("walk")) {
          this.renderable.setCurrentAnimation("walk");
        }
      } else {
          if (!this.renderable.isCurrentAnimation("swordWalk")) {
            this.renderable.setCurrentAnimation("swordWalk");
          }
        }
    } else if (me.input.isKeyPressed('right')) {
      // unflip the sprite
      this.renderable.flipX(false);
      // update the entity velocity
      this.body.vel.x += this.body.accel.x * me.timer.tick;
      // change to the walking animation
      if (mode == false) {
        if (!this.renderable.isCurrentAnimation("walk")) {
          this.renderable.setCurrentAnimation("walk");
        }
      } else {
          if (!this.renderable.isCurrentAnimation("swordWalk")) {
            this.renderable.setCurrentAnimation("swordWalk");
          }
        }
    } else {
      this.body.vel.x = 0;
      // change to the standing animation
      if (mode == false){
        if (this.renderable.isCurrentAnimation("walk"))
       	 this.renderable.setCurrentAnimation("stand");
      } else {
          if (this.renderable.isCurrentAnimation("swordWalk"))
            this.renderable.setCurrentAnimation("swordStand");
      }
    }
   
    if (me.input.isKeyPressed('jump')) {
      // make sure we are not already jumping or falling
      if (!this.body.jumping && !this.body.falling) {
        // set current vel to the maximum defined value
        // gravity will then do the rest
        this.body.vel.y = -this.body.maxVel.y * me.timer.tick;
        // set the jumping flag
        this.body.jumping = true;
      }
    }
    if (me.input.isKeyPressed('X')) {
      if (mode == true){
      	this.body.vel.x = 0;
      	this.renderable.setCurrentAnimation("attack", "swordStand");
      }
 	} 
 	
    // apply physics to the body (this moves the entity)
    this.body.update(dt);
 
    // handle collisions against other shapes
    me.collision.check(this);
 
    // return true if we moved or if the renderable was updated
    return (this._super(me.Entity, 'update', [dt]) || this.body.vel.x !== 0 || this.body.vel.y !== 0);
  },
   
  /**
   * colision handler
   * (called when colliding with other objects)
   */
  onCollision : function (response, other) {
    // Make all other objects solid
    return true;
  }
});

/*----------------
  a Sword entity
 ----------------- */
game.sword = me.CollectableEntity.extend({
  // extending the init function is not mandatory
  // unless you need to add some extra initialization
  init: function(x, y, settings) {
    // call the parent constructor
    this._super(me.CollectableEntity, 'init', [x, y , settings]);
 
  },
 
  // this function is called by the engine, when
  // an object is touched by something (here collected)
  onCollision : function (response, other) {
    // do something when collected
 
    // make sure it cannot be collected "again"
    this.body.setCollisionMask(me.collision.types.NO_OBJECT);
    mode = true;
    // remove it
    me.game.world.removeChild(this);
     
    return false
  }
});

/**
 * Enemy Entity
 */
game.EnemyEntity = me.Entity.extend(
{    
    init: function (x, y, settings)
    {
        // define this here instead of tiled
        settings.image = "wheelie_right";
          
        // save the area size defined in Tiled
        var width = settings.width;
        var height = settings.height;

        // adjust the size setting information to match the sprite size
        // so that the entity object is created with the right size
        settings.spritewidth = settings.width = 64;
        settings.spritewidth = settings.height = 64;
        
        // call the parent constructor
        this._super(me.Entity, 'init', [x, y , settings]);
        
        // set start/end position based on the initial area size
        x = this.pos.x;
        this.startX = x;
        this.endX   = x + width - settings.spritewidth;
        this.pos.x  = x + width - settings.spritewidth;

        // manually update the entity bounds as we manually change the position
        this.updateBounds();

        // to remember which side we were walking
        this.walkLeft = false;

        // walking & jumping speed
        this.body.setVelocity(1, 6);
    },
        
    // manage the enemy movement
    update : function (dt)
    {            
        if (this.alive)
        {
            if (this.walkLeft && this.pos.x <= this.startX)
            {
                this.walkLeft = false;
            }
            else if (!this.walkLeft && this.pos.x >= this.endX)
            {
                this.walkLeft = true;
            }
            
            this.renderable.flipX(this.walkLeft);
            this.body.vel.x += (this.walkLeft) ? -this.body.accel.x * me.timer.tick : this.body.accel.x * me.timer.tick;

        }
        else
        {
            this.body.vel.x = 0;
        }
        // check & update movement
        this.body.update(dt);
        
        // handle collisions against other shapes
        me.collision.check(this);
            
        // return true if we moved or if the renderable was updated
        return (this._super(me.Entity, 'update', [dt]) || this.body.vel.x !== 0 || this.body.vel.y !== 0);
    },
    
    /**
     * colision handler
     * (called when colliding with other objects)
     */
    onCollision : function (response, other) {
        if (response.b.body.collisionType !== me.collision.types.WORLD_SHAPE) {
            // res.y >0 means touched by something on the bottom
            // which mean at top position for this one
            if (this.alive && (response.overlapV.y > 0) && response.a.body.falling) {
                this.renderable.flicker(750);
            }
            if (this.alive && (response.overlapV.x < 0)){
              this.renderable.flicker(750);
              setTimeout(function () {
                 this.renderable.flicker(750);
              }, 1000);
              this.body.setCollisionMask(me.collision.types.NO_OBJECT);
              me.game.world.removeChild(this);
              this.alive = false;
            }
            return false;
        }
        // Make all other objects solid
        return true;
    }
});